@@ -28,7 +28,7 @@ class PasswordRevisionMapper extends AbstractRevisionMapper {
      *
      * @return bool
      */
-    public function hasDuplicates(string $hash, string $model, string $user = null): bool {
+    public function hasDuplicates(string $hash, string $model, ?string $user = null): bool {
         $sql = $this->getStatement();
 
         $sql->andWhere(
@@ -52,4 +52,4 @@ class PasswordRevisionMapper extends AbstractRevisionMapper {
     public function findAllWithGoodStatus(): array {
         return $this->findAllByField('status', 2, IQueryBuilder::PARAM_INT, 'neq');
     }
-}
\ No newline at end of file
+}
