@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\Folder;
@@ -17,19 +21,13 @@ use OCP\EventDispatcher\Event;
  */
 class GenericFolderEvent extends Event {
 
-    /**
-     * @var Folder
-     */
-    protected Folder $Folder;
-
     /**
      * GenericFolderEvent constructor.
      *
      * @param Folder $Folder
      */
-    public function __construct(Folder $Folder) {
+    public function __construct(protected Folder $Folder) {
         parent::__construct();
-        $this->Folder = $Folder;
     }
 
     /**
