@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\Keychain;
@@ -17,26 +21,14 @@ use OCP\EventDispatcher\Event;
  */
 class AfterKeychainClonedEvent extends Event {
 
-    /**
-     * @var Keychain
-     */
-    protected Keychain $original;
-
-    /**
-     * @var Keychain
-     */
-    protected Keychain $clone;
-
     /**
      * BeforeKeychainClonedEvent constructor.
      *
      * @param Keychain $original
      * @param Keychain $clone
      */
-    public function __construct(Keychain $original, Keychain $clone) {
+    public function __construct(protected Keychain $original, protected Keychain $clone) {
         parent::__construct();
-        $this->original = $original;
-        $this->clone = $clone;
     }
 
     /**
