@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\PasswordTagRelation;
@@ -17,26 +21,14 @@ use OCP\EventDispatcher\Event;
  */
 class AfterPasswordTagRelationClonedEvent extends Event {
 
-    /**
-     * @var PasswordTagRelation
-     */
-    protected PasswordTagRelation $original;
-
-    /**
-     * @var PasswordTagRelation
-     */
-    protected PasswordTagRelation $clone;
-
     /**
      * BeforePasswordTagRelationClonedEvent constructor.
      *
      * @param PasswordTagRelation $original
      * @param PasswordTagRelation $clone
      */
-    public function __construct(PasswordTagRelation $original, PasswordTagRelation $clone) {
+    public function __construct(protected PasswordTagRelation $original, protected PasswordTagRelation $clone) {
         parent::__construct();
-        $this->original = $original;
-        $this->clone = $clone;
     }
 
     /**
