@@ -1,8 +1,12 @@
 <?php
-/**
+/*
+ * @copyright 2025 Passwords App
+ *
+ * @author Marius David Wieschollek
+ * @license AGPL-3.0
+ *
  * This file is part of the Passwords App
- * created by Marius David Wieschollek
- * and licensed under the AGPL.
+ * created by Marius David Wieschollek.
  */
 
 namespace OCA\Passwords\Events\Registration;
@@ -17,19 +21,13 @@ use OCP\EventDispatcher\Event;
  */
 class GenericRegistrationEvent extends Event {
 
-    /**
-     * @var Registration
-     */
-    protected Registration $Registration;
-
     /**
      * GenericRegistrationEvent constructor.
      *
      * @param Registration $Registration
      */
-    public function __construct(Registration $Registration) {
+    public function __construct(protected Registration $Registration) {
         parent::__construct();
-        $this->Registration = $Registration;
     }
 
     /**
