@@ -21,20 +21,19 @@ use Throwable;
  * @package OCA\Passwords\Exception\SecurityCheck
  */
 class PasswordDatabaseDownloadException extends Exception {
-    const EXCEPTION_CODE    = 106;
-    const EXCEPTION_MESSAGE = '';
+    const EXCEPTION_CODE       = 106;
 
     /**
      * PasswordDatabaseDownloadException constructor.
      *
      * @param Throwable|null $previous
      */
-    public function __construct(Throwable $previous = null) {
+    public function __construct(?Throwable $previous = null) {
         $message = 'Failed to download common passwords zip file';
         if($previous instanceof ClientException) {
-            $message .= " HTTP {$previous->getResponse()->getStatusCode()}";
+            $message .= ": HTTP {$previous->getResponse()->getStatusCode()}";
         } else if($previous instanceof Throwable) {
-            $message .= ' '.$previous->getMessage();
+            $message .= ': '.$previous->getMessage();
         }
 
         parent::__construct($message, static::EXCEPTION_CODE, $previous);
